@@ -17,6 +17,10 @@ class TestRaises(object):
     def test_raises_exec(self):
         pytest.raises(ValueError, "a,x = []")
 
+    def test_raises_exec_correct_filename(self):
+        excinfo = pytest.raises(ValueError, 'int("s")')
+        assert __file__ in excinfo.traceback[-1].path
+
     def test_raises_syntax_error(self):
         pytest.raises(SyntaxError, "qwe qwe qwe")
 
@@ -33,6 +37,11 @@ class TestRaises(object):
         except pytest.raises.Exception:
             pass
 
+    def test_raises_falsey_type_error(self):
+        with pytest.raises(TypeError):
+            with pytest.raises(AssertionError, match=0):
+                raise AssertionError("ohai")
+
     def test_raises_repr_inflight(self):
         """Ensure repr() on an exception info inside a pytest.raises with block works (#4386)"""
 
@@ -186,7 +195,8 @@ class TestRaises(object):
             pass
 
         with pytest.raises(
-            Failed, match="DID NOT RAISE <class 'raises.ClassLooksIterableException'>"
+            Failed,
+            match=r"DID NOT RAISE <class 'raises(\..*)*ClassLooksIterableException'>",
         ):
             pytest.raises(ClassLooksIterableException, lambda: None)
 
